from __future__ import absolute_import, division, print_function

import importlib
import logging
import os
import sys
from time import sleep

import yaml


def run_task(task, paths):
    script = task['script']
    func = task['func']
    params = task.get('params', [])

    loglevel = task.get('loglevel', None)
    if loglevel is not None:
        logging.getLogger().setLevel(loglevel.upper())

    paths = task['paths']
    sys.path = [x for x in paths]
    for path in paths:
        path = path.replace('~', os.environ['HOME'])
        sys.path.insert(0, path)

    module = importlib.import_module(script)
    main = getattr(module, func)

    kwargs = {}
    for param in params:
        if isinstance(param, dict):
            kwargs.update(param)

    args_str = ', '.join(['{k}={v}'.format(k=k, v=kwargs[k]) for k in kwargs])
    logging.info('evaluating `%s.%s(%s)`', script, func, args_str)

    sleep(0.1)
    result = main(**kwargs)

    return {'task': task, 'result': result}


def run_yaml(fn):
    paths = [x for x in sys.path]
    with open(fn) as f:
        cfg = yaml.load(f.read())
    run_task(cfg, paths)



from __future__ import absolute_import, division, print_function

import sys
import logging

from move_carrots import run_yaml

if __name__ == '__main__':
    for yaml_fn in sys.argv[1:]:
        logging.info('run_task on %s', yaml_fn)
        run_yaml(yaml_fn)



#!/usr/bin/env python
# coding: utf8

from __future__ import absolute_import, division, print_function

from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = f.read()

setup(
    name='move-carrots',
    license='MIT',
    version='0.1.1',
    packages=find_packages(exclude=['tests*']),
    description='Simple helper for reproducible (research) experiments.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=['pyyaml'],
    url='https://gitlab.com/Pinle/move-carrots',
    author='Pinle',
    author_email='',
    py_modules=['mcar'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
